.. py:function:: sf_fermi_dirac_half_e(x [, ret, result.val, result.err])

    Wrapper for :c:func:`gsl_sf_fermi_dirac_half_e`
    c code signature: int gsl_sf_fermi_dirac_half_e(const double x, gsl_sf_result* result)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Id__Rl__Ord`
    
    :param double x: positional argument 0
    :param int ret: positional argument 1
    :param double result.val: positional argument 2
    :param double result.err: positional argument 3
    :rtype:  tuple(:param int ret: positional argument 1, :param double result.val: positional argument 2, :param double result.err: positional argument 3) 
    :return: result 

.. py:function:: sf_fermi_dirac_2_e(x [, ret, result.val, result.err])

    Wrapper for :c:func:`gsl_sf_fermi_dirac_2_e`
    c code signature: int gsl_sf_fermi_dirac_2_e(const double x, gsl_sf_result* result)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Id__Rl__Ord`
    
    :param double x: positional argument 0
    :param int ret: positional argument 1
    :param double result.val: positional argument 2
    :param double result.err: positional argument 3
    :rtype:  tuple(:param int ret: positional argument 1, :param double result.val: positional argument 2, :param double result.err: positional argument 3) 
    :return: result 

.. py:function:: sf_fermi_dirac_1_e(x [, ret, result.val, result.err])

    Wrapper for :c:func:`gsl_sf_fermi_dirac_1_e`
    c code signature: int gsl_sf_fermi_dirac_1_e(const double x, gsl_sf_result* result)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Id__Rl__Ord`
    
    :param double x: positional argument 0
    :param int ret: positional argument 1
    :param double result.val: positional argument 2
    :param double result.err: positional argument 3
    :rtype:  tuple(:param int ret: positional argument 1, :param double result.val: positional argument 2, :param double result.err: positional argument 3) 
    :return: result 

.. py:function:: sf_fermi_dirac_int(j, x [, ret])

    Wrapper for :c:func:`gsl_sf_fermi_dirac_int`
    c code signature: double gsl_sf_fermi_dirac_int(const int j, const double x)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Il_d__Rd__O`
    
    :param int j: positional argument 0
    :param double x: positional argument 1
    :param double ret: positional argument 2
    :rtype:  double 
    :return: result 

.. py:function:: sf_fermi_dirac_m1(x [, ret])

    Wrapper for :c:func:`gsl_sf_fermi_dirac_m1`
    c code signature: double gsl_sf_fermi_dirac_m1(const double x)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Id__Rd__O`
    
    :param double x: positional argument 0
    :param double ret: positional argument 1
    :rtype:  double 
    :return: result 

.. py:function:: sf_fermi_dirac_m1_e(x [, ret, result.val, result.err])

    Wrapper for :c:func:`gsl_sf_fermi_dirac_m1_e`
    c code signature: int gsl_sf_fermi_dirac_m1_e(const double x, gsl_sf_result* result)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Id__Rl__Ord`
    
    :param double x: positional argument 0
    :param int ret: positional argument 1
    :param double result.val: positional argument 2
    :param double result.err: positional argument 3
    :rtype:  tuple(:param int ret: positional argument 1, :param double result.val: positional argument 2, :param double result.err: positional argument 3) 
    :return: result 

.. py:function:: sf_fermi_dirac_mhalf_e(x [, ret, result.val, result.err])

    Wrapper for :c:func:`gsl_sf_fermi_dirac_mhalf_e`
    c code signature: int gsl_sf_fermi_dirac_mhalf_e(const double x, gsl_sf_result* result)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Id__Rl__Ord`
    
    :param double x: positional argument 0
    :param int ret: positional argument 1
    :param double result.val: positional argument 2
    :param double result.err: positional argument 3
    :rtype:  tuple(:param int ret: positional argument 1, :param double result.val: positional argument 2, :param double result.err: positional argument 3) 
    :return: result 

.. py:function:: sf_fermi_dirac_inc_0(x, b [, ret])

    Wrapper for :c:func:`gsl_sf_fermi_dirac_inc_0`
    c code signature: double gsl_sf_fermi_dirac_inc_0(const double x, const double b)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Id_d__Rd__O`
    
    :param double x: positional argument 0
    :param double b: positional argument 1
    :param double ret: positional argument 2
    :rtype:  double 
    :return: result 

.. py:function:: sf_fermi_dirac_0_e(x [, ret, result.val, result.err])

    Wrapper for :c:func:`gsl_sf_fermi_dirac_0_e`
    c code signature: int gsl_sf_fermi_dirac_0_e(const double x, gsl_sf_result* result)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Id__Rl__Ord`
    
    :param double x: positional argument 0
    :param int ret: positional argument 1
    :param double result.val: positional argument 2
    :param double result.err: positional argument 3
    :rtype:  tuple(:param int ret: positional argument 1, :param double result.val: positional argument 2, :param double result.err: positional argument 3) 
    :return: result 

.. py:function:: sf_fermi_dirac_0(x [, ret])

    Wrapper for :c:func:`gsl_sf_fermi_dirac_0`
    c code signature: double gsl_sf_fermi_dirac_0(const double x)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Id__Rd__O`
    
    :param double x: positional argument 0
    :param double ret: positional argument 1
    :rtype:  double 
    :return: result 

.. py:function:: sf_fermi_dirac_2(x [, ret])

    Wrapper for :c:func:`gsl_sf_fermi_dirac_2`
    c code signature: double gsl_sf_fermi_dirac_2(const double x)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Id__Rd__O`
    
    :param double x: positional argument 0
    :param double ret: positional argument 1
    :rtype:  double 
    :return: result 

.. py:function:: sf_fermi_dirac_1(x [, ret])

    Wrapper for :c:func:`gsl_sf_fermi_dirac_1`
    c code signature: double gsl_sf_fermi_dirac_1(const double x)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Id__Rd__O`
    
    :param double x: positional argument 0
    :param double ret: positional argument 1
    :rtype:  double 
    :return: result 

.. py:function:: sf_fermi_dirac_3half_e(x [, ret, result.val, result.err])

    Wrapper for :c:func:`gsl_sf_fermi_dirac_3half_e`
    c code signature: int gsl_sf_fermi_dirac_3half_e(const double x, gsl_sf_result* result)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Id__Rl__Ord`
    
    :param double x: positional argument 0
    :param int ret: positional argument 1
    :param double result.val: positional argument 2
    :param double result.err: positional argument 3
    :rtype:  tuple(:param int ret: positional argument 1, :param double result.val: positional argument 2, :param double result.err: positional argument 3) 
    :return: result 

.. py:function:: sf_fermi_dirac_inc_0_e(x, b [, ret, result.val, result.err])

    Wrapper for :c:func:`gsl_sf_fermi_dirac_inc_0_e`
    c code signature: int gsl_sf_fermi_dirac_inc_0_e(const double x, const double b, gsl_sf_result* result)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Id_d__Rl__Ord`
    
    :param double x: positional argument 0
    :param double b: positional argument 1
    :param int ret: positional argument 2
    :param double result.val: positional argument 3
    :param double result.err: positional argument 4
    :rtype:  tuple(:param int ret: positional argument 2, :param double result.val: positional argument 3, :param double result.err: positional argument 4) 
    :return: result 

.. py:function:: sf_fermi_dirac_half(x [, ret])

    Wrapper for :c:func:`gsl_sf_fermi_dirac_half`
    c code signature: double gsl_sf_fermi_dirac_half(const double x)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Id__Rd__O`
    
    :param double x: positional argument 0
    :param double ret: positional argument 1
    :rtype:  double 
    :return: result 

.. py:function:: sf_fermi_dirac_mhalf(x [, ret])

    Wrapper for :c:func:`gsl_sf_fermi_dirac_mhalf`
    c code signature: double gsl_sf_fermi_dirac_mhalf(const double x)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Id__Rd__O`
    
    :param double x: positional argument 0
    :param double ret: positional argument 1
    :rtype:  double 
    :return: result 

.. py:function:: sf_fermi_dirac_int_e(j, x [, ret, result.val, result.err])

    Wrapper for :c:func:`gsl_sf_fermi_dirac_int_e`
    c code signature: int gsl_sf_fermi_dirac_int_e(const int j, const double x, gsl_sf_result* result)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Il_d__Rl__Ord`
    
    :param int j: positional argument 0
    :param double x: positional argument 1
    :param int ret: positional argument 2
    :param double result.val: positional argument 3
    :param double result.err: positional argument 4
    :rtype:  tuple(:param int ret: positional argument 2, :param double result.val: positional argument 3, :param double result.err: positional argument 4) 
    :return: result 

.. py:function:: sf_fermi_dirac_3half(x [, ret])

    Wrapper for :c:func:`gsl_sf_fermi_dirac_3half`
    c code signature: double gsl_sf_fermi_dirac_3half(const double x)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Id__Rd__O`
    
    :param double x: positional argument 0
    :param double ret: positional argument 1
    :rtype:  double 
    :return: result 

